@@ -18,7 +18,6 @@ void null_plug(void *ptr) { }
    note that since we do not have the needed functions to manipulate the data structures *** YET ***
 */
 
-
 unsigned char saturate(int in) {
   if (in>255) { return 255; }
   else if (in>0) return in;
@@ -33,17 +32,16 @@ void lin_stretch(void *INP) {
   int i,bytes,x,y;
   int info[4];
 
-
-  if ( !getVOID("image",&im) ) { fprintf(stderr,"Error: image is missing\n"); }
+  if ( !getOBJ("image","Imager::ImgRaw",&im) ) { fprintf(stderr,"Error: image is missing\n"); }
   if ( !getINT("a",&a) ) { fprintf(stderr,"Error: a is missing\n"); }
   if ( !getINT("b",&b) ) { fprintf(stderr,"Error: b is missing\n"); }
   
-  /*  printf("parameters: (im 0x%x,a %d,b %d)\n",im,a,b); */
+  /*   fprintf(stderr,"parameters: (im 0x%x,a %d,b %d)\n",im,a,b);*/
   bytes=im->bytes;
 
-  /*  i_img_info(im,info); */
-  /*  for(i=0;i<4;i++) { printf("%d: %d\n",i,info[i]); } */
-  /*  printf("image info:\n size (%d,%d)\n channels (%d)\n channel mask (%d)\n bytes (%d)\n",im->xsize,im->ysize,im->channels,im->ch_mask,im->bytes); */
+  i_img_info(im,info); 
+  for(i=0;i<4;i++) { printf("%d: %d\n",i,info[i]); } 
+  printf("image info:\n size (%d,%d)\n channels (%d)\n channel mask (%d)\n bytes (%d)\n",im->xsize,im->ysize,im->channels,im->ch_mask,im->bytes); 
 
   for(y=0;y<im->ysize;y++) for(x=0;x<im->xsize;x++) {
     i_gpix(im,x,y,&rcolor);
