@@ -7,7 +7,7 @@ i_img *
 i_readppm(int fd) {
   i_img* im;
   int type;
-  int ic,rc,x,y,ind;
+  int ic=0,rc,x,y,ind;
   char buf[256];
   memset(buf,0,256);
   read(fd,buf,3);
@@ -21,7 +21,7 @@ i_readppm(int fd) {
   if (!strncmp(buf,"P3\n",3)) { type=2; mm_log((1,"i_readppm: Type is P3\n")); }
   if (!type) { mm_log((1,"Format is not ppm\n")); return NULL; }
 
-  while(rc=myread(fd,buf,1)>0) { 
+  while( (rc=myread(fd,buf,1)) >0) { 
     if (buf[0] == '#') ic=1;
     if (!ic) { break; }
     if (buf[0] == '\n') ic=0;
@@ -31,7 +31,7 @@ i_readppm(int fd) {
   
   memset(buf,0,256);
   ind=0;
-  while(rc=myread(fd,&buf[ind],1)>0) { 
+  while( (rc=myread(fd,&buf[ind],1))>0) { 
     if (buf[ind] == '\n') break;
     /*    fprintf(stderr,"%c",buf[ind]); */
     ind++;
@@ -40,7 +40,7 @@ i_readppm(int fd) {
   sscanf(buf,"%d %d\n",&x,&y);
   mm_log((1,"i_readppm: x=%d y=%d\n",x,y));
   
-  while(rc=myread(fd,&buf[0],1)>0) { if (buf[0] == '\n') break; }
+  while( (rc=myread(fd,&buf[0],1))>0) { if (buf[0] == '\n') break; }
   
   im=i_img_empty(NULL,x,y);
   
@@ -56,7 +56,7 @@ i_readppm(int fd) {
 undef_int
 i_writeppm(i_img *im,int fd) {
   char header[255];
-  int rc,bc;
+  int rc;
 
   mm_log((1,"i_writeppm(im* 0x%x,fd %d)\n",im,fd));
   if (im->channels!=3) {
